@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -22,11 +22,14 @@
  */
 package jdk.vm.ci.hotspot.aarch64;
 
+import static java.util.Collections.emptyMap;
 import static jdk.vm.ci.common.InitTimer.timer;
 
 import java.util.EnumSet;
+import java.util.Map;
 
 import jdk.vm.ci.aarch64.AArch64;
+import jdk.vm.ci.aarch64.AArch64.CPUFeature;
 import jdk.vm.ci.code.Architecture;
 import jdk.vm.ci.code.RegisterConfig;
 import jdk.vm.ci.code.TargetDescription;
@@ -43,56 +46,15 @@ import jdk.vm.ci.runtime.JVMCIBackend;
 
 public class AArch64HotSpotJVMCIBackendFactory implements HotSpotJVMCIBackendFactory {
 
-    private static EnumSet<AArch64.CPUFeature> computeFeatures(@SuppressWarnings("unused") AArch64HotSpotVMConfig config) {
+    private static EnumSet<AArch64.CPUFeature> computeFeatures(AArch64HotSpotVMConfig config) {
         // Configure the feature set using the HotSpot flag settings.
-        EnumSet<AArch64.CPUFeature> features = EnumSet.noneOf(AArch64.CPUFeature.class);
-
-        if ((config.vmVersionFeatures & config.aarch64FP) != 0) {
-            features.add(AArch64.CPUFeature.FP);
-        }
-        if ((config.vmVersionFeatures & config.aarch64ASIMD) != 0) {
-            features.add(AArch64.CPUFeature.ASIMD);
-        }
-        if ((config.vmVersionFeatures & config.aarch64EVTSTRM) != 0) {
-            features.add(AArch64.CPUFeature.EVTSTRM);
-        }
-        if ((config.vmVersionFeatures & config.aarch64AES) != 0) {
-            features.add(AArch64.CPUFeature.AES);
-        }
-        if ((config.vmVersionFeatures & config.aarch64PMULL) != 0) {
-            features.add(AArch64.CPUFeature.PMULL);
-        }
-        if ((config.vmVersionFeatures & config.aarch64SHA1) != 0) {
-            features.add(AArch64.CPUFeature.SHA1);
-        }
-        if ((config.vmVersionFeatures & config.aarch64SHA2) != 0) {
-            features.add(AArch64.CPUFeature.SHA2);
-        }
-        if ((config.vmVersionFeatures & config.aarch64CRC32) != 0) {
-            features.add(AArch64.CPUFeature.CRC32);
-        }
-        if ((config.vmVersionFeatures & config.aarch64LSE) != 0) {
-            features.add(AArch64.CPUFeature.LSE);
-        }
-        if ((config.vmVersionFeatures & config.aarch64STXR_PREFETCH) != 0) {
-            features.add(AArch64.CPUFeature.STXR_PREFETCH);
-        }
-        if ((config.vmVersionFeatures & config.aarch64A53MAC) != 0) {
-            features.add(AArch64.CPUFeature.A53MAC);
-        }
-        if ((config.vmVersionFeatures & config.aarch64DMB_ATOMICS) != 0) {
-            features.add(AArch64.CPUFeature.DMB_ATOMICS);
-        }
-
-        return features;
+        Map<String, Long> constants = config.getStore().getConstants();
+        return HotSpotJVMCIBackendFactory.convertFeatures(CPUFeature.class, constants, config.vmVersionFeatures, emptyMap());
     }
 
-    private static EnumSet<AArch64.Flag> computeFlags(@SuppressWarnings("unused") AArch64HotSpotVMConfig config) {
+    private static EnumSet<AArch64.Flag> computeFlags(AArch64HotSpotVMConfig config) {
         EnumSet<AArch64.Flag> flags = EnumSet.noneOf(AArch64.Flag.class);
 
-        if (config.useBarriersForVolatile) {
-            flags.add(AArch64.Flag.UseBarriersForVolatile);
-        }
         if (config.useCRC32) {
             flags.add(AArch64.Flag.UseCRC32);
         }
@@ -127,8 +89,12 @@ public class AArch64HotSpotJVMCIBackendFactory implements HotSpotJVMCIBackendFac
         return new HotSpotConstantReflectionProvider(runtime);
     }
 
-    private static RegisterConfig createRegisterConfig(TargetDescription target) {
-        return new AArch64HotSpotRegisterConfig(target);
+    private static RegisterConfig createRegisterConfig(AArch64HotSpotVMConfig config, TargetDescription target) {
+        // ARMv8 defines r18 as being available to the platform ABI. Windows
+        // and Darwin use it for such. Linux doesn't assign it and thus r18 can
+        // be used as an additional register.
+        boolean canUsePlatformRegister = config.linuxOs;
+        return new AArch64HotSpotRegisterConfig(target, config.useCompressedOops, canUsePlatformRegister);
     }
 
     protected HotSpotCodeCacheProvider createCodeCache(HotSpotJVMCIRuntime runtime, TargetDescription target, RegisterConfig regConfig) {
@@ -167,7 +133,7 @@ public class AArch64HotSpotJVMCIBackendFactory implements HotSpotJVMCIBackendFac
                 metaAccess = createMetaAccess(runtime);
             }
             try (InitTimer rt = timer("create RegisterConfig")) {
-                regConfig = createRegisterConfig(target);
+                regConfig = createRegisterConfig(config, target);
             }
             try (InitTimer rt = timer("create CodeCache provider")) {
                 codeCache = createCodeCache(runtime, target, regConfig);
