@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -85,21 +81,6 @@ public class FormatData_ja extends ListResourceBundle {
                "12\u6708",
                "",
             };
-        final String[] metaValue_MonthNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-               "5",
-               "6",
-               "7",
-               "8",
-               "9",
-               "10",
-               "11",
-               "12",
-               "",
-            };
         final String[] metaValue_DayNames = new String[] {
                "\u65e5\u66dc\u65e5",
                "\u6708\u66dc\u65e5",
@@ -124,21 +105,25 @@ public class FormatData_ja extends ListResourceBundle {
                "\u7b2c3\u56db\u534a\u671f",
                "\u7b2c4\u56db\u534a\u671f",
             };
-        final String[] metaValue_QuarterAbbreviations = new String[] {
+        final String[] metaValue_standalone_QuarterAbbreviations = new String[] {
                "Q1",
                "Q2",
                "Q3",
                "Q4",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u5348\u524d",
                "\u5348\u5f8c",
+               "\u771f\u591c\u4e2d",
+               "\u6b63\u5348",
+               "\u671d",
+               "",
+               "\u663c",
+               "",
+               "\u5915\u65b9",
+               "",
+               "\u591c",
+               "\u591c\u4e2d",
             };
         final String[] metaValue_long_Eras = new String[] {
                "\u7d00\u5143\u524d",
@@ -156,6 +141,27 @@ public class FormatData_ja extends ListResourceBundle {
                "{1} {0}",
                "{1} {0}",
             };
+        final String[] metaValue_buddhist_MonthNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+               "5",
+               "6",
+               "7",
+               "8",
+               "9",
+               "10",
+               "11",
+               "12",
+               "",
+            };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u4ecf\u66a6",
@@ -188,7 +194,7 @@ public class FormatData_ja extends ListResourceBundle {
             };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u6c11\u56fd\u524d",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_roc_Eras = new String[] {
                "\u6c11\u56fd\u524d",
@@ -253,10 +259,10 @@ public class FormatData_ja extends ListResourceBundle {
                     "GGGGGy/M/d",
                 }
             },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
+            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "calendarname.islamic-civil", "\u30a4\u30b9\u30e9\u30e0\u6b74(\u5b9a\u5468\u671f\u3001\u516c\u6c11\u7d00\u5143)" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -276,7 +282,7 @@ public class FormatData_ja extends ListResourceBundle {
             { "roc.MonthAbbreviations", metaValue_MonthNames },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -295,9 +301,10 @@ public class FormatData_ja extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns",
                 new String[] {
                     "GGGGy\u5e74M\u6708d\u65e5EEEE",
@@ -313,48 +320,32 @@ public class FormatData_ja extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u5348\u524d/\u5348\u5f8c" },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u4e2d\u83ef\u6c11\u56fd\u66a6" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u6708" },
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "\u79d2" },
-            { "islamic.MonthNarrows",
-                new String[] {
-                    "1",
-                    "2",
-                    "3",
-                    "4",
-                    "5",
-                    "6",
-                    "7",
-                    "8",
-                    "9",
-                    "10",
-                    "11",
-                    "12",
-                    "",
-                }
-            },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u30a4\u30b9\u30e9\u30e0\u66a6" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:19:00-23:00;afternoon1:12:00-16:00;morning1:04:00-12:00;evening1:16:00-19:00;night2:23:00-04:00" },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
             { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "timezone.regionFormat", "{0}\u6642\u9593" },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "standalone.DayNarrows", metaValue_DayAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -364,14 +355,13 @@ public class FormatData_ja extends ListResourceBundle {
             { "islamic.DayNarrows", metaValue_DayAbbreviations },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "\u30bf\u30a4\u30e0\u30be\u30fc\u30f3" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_roc_DatePatterns },
             { "field.weekday", "\u66dc\u65e5" },
@@ -380,7 +370,7 @@ public class FormatData_ja extends ListResourceBundle {
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
@@ -390,9 +380,9 @@ public class FormatData_ja extends ListResourceBundle {
             { "roc.MonthNames", metaValue_MonthNames },
             { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "\u9031" },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayAbbreviations },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_roc_DatePatterns },
@@ -439,7 +429,6 @@ public class FormatData_ja extends ListResourceBundle {
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
